## What's Changed

### 修复

- 修复钉钉适配器中"回复消息 At 发送人"功能失效的问题
- 修复 Xinference STT 在部分情况下无法使用的问题
- 修复"会话隔离"功能在非默认配置下无法生效的问题
- 修复部分 LLM 中转商因 token 使用情况不符合 OpenAI 标准接口规范导致请求报错的问题
- 修复 Deepseek 模型开启思考模式后工具调用报错的问题
- 修复部分操作系统环境下 pip 安装依赖时出现 `UnicodeDecodeError` 错误的问题

### 优化

- 全面优化对思考型模型的支持（如 Anthropic Extended Thinking、Deepseek 思考模式），完整回传 thinking 内容，提升模型推理性能
- 优化 WebUI 记忆侧边栏中"更多功能"和"平台日志"模块的展开状态记忆
- 为 MiniMax TTS 新增 "auto" 音色情绪选项，支持模型根据文本内容自动选择情绪
- 优化备份功能，支持大文件分片下载
- 为 WebSocket 连接添加 max_size 参数，以处理更大的消息并防止接收来自 Satori 平台的大负载时连接断开
- 优化插件安装流程，通过文件安装插件时，若插件已加载则先终止再重新加载，避免重复加载
- 知识库支持将 overlap 参数设置为 0

### 新增

- 为 `dict` 类型的 Schema 新增 JSON value 和 template schema 功能。详见 [dict-类型的-schema](https://docs.astrbot.app/dev/star/guides/plugin-config.html#dict-%E7%B1%BB%E5%9E%8B%E7%9A%84-schema)。
- 新增 `template_list` 类型的 Schema，支持渲染指定 template 下的列表。详见 [template-list-类型的-schema](https://docs.astrbot.app/dev/star/guides/plugin-config.html#template-list-%E7%B1%BB%E5%9E%8B%E7%9A%84-schema)。